package
Version:
v0.0.37
Opens a new window with list of versions in this module.
Published: Feb 7, 2025
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type LogInfo struct {
Method string `json:"method"`
Req string `json:"req"`
LogId string `json:"logId"`
TimeString string `json:"logId"`
TimeUnix int64 `json:"timeUnix"`
UserId int64 `json:"user_id"`
}
Source Files
¶
Directories
¶
Click to show internal directories.
Click to hide internal directories.